@@ -268,6 +268,9 @@ def get_parser():
     parser.add_argument(
         '--region',
         help='Region', type=str)
+    parser.add_argument(
+        '--profile',
+        help='AWS Profile', type=str)
     parser.add_argument(
         '--compact',
         help='Display Stacks-Output in compact form',
