@@ -9,6 +9,7 @@ def get_base_data(stack):
         'before': {},
         'after': {},
         'changed': {},
+        'parameter_not_empty': [],
     }
 
     stack_outputs = outputs.get(stack)
@@ -20,6 +21,15 @@ def get_base_data(stack):
     if stack_parameters:
         data['c_parameters'] = stack_parameters
 
+        # add parameters too, this way i can show them using show command
+        for n, v in data['c_parameters'].items():
+            if (not n.startswith('Env')
+                    and n not in ['UpdateMode']
+                    and v != '' and ',,,' not in v):
+                data['parameter_not_empty'].append(n)
+            if n not in data:
+                data[n] = v
+
     return data
 
 
