@@ -13,8 +13,9 @@ def get(data):
     table.padding_width = 1
     table.field_names = fields
     for n in data:
-        table.add_row(['None' if (i not in n or not n[i]) else n[i]
-                      for i in fields])
+        table.add_row([
+            'Null' if (i not in n or not n[i]) else f'{n[i]} *'
+            if i in n['parameter_not_empty'] else n[i] for i in fields])
 
     table.sortby = fields[0]
     table.reversesort = True
